@@ -2,9 +2,11 @@ import time
 
 import torch
 
+from yqn_pytorch_framework.device import tensor_load_device
+
 
 def model_time_estimate(device, get_model, loop=100):
-    model = get_model().to(device)
+    model = tensor_load_device(get_model(), device).eval()
     torch.cuda.synchronize(device)
     start = time.time()
     with torch.no_grad():
